@@ -9,9 +9,7 @@ from typing import BinaryIO, Callable, Generic, Optional, Sequence, TypeVar
 
 import click
 from cryptography import x509
-from cryptography.hazmat.primitives import serialization
-from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePublicKey
-from ecdsa import NIST256p, SigningKey
+from cryptography.hazmat.primitives.asymmetric import ec
 from nitrokey.trussed import (
     FirmwareContainer,
     Model,
@@ -19,9 +17,11 @@ from nitrokey.trussed import (
     TrussedBase,
     TrussedBootloader,
     TrussedDevice,
+    Version,
     parse_firmware_image,
+    updates,
 )
-from nitrokey.trussed.admin_app import BootMode
+from nitrokey.trussed.admin_app import BootMode, InitStatus, Status
 from nitrokey.trussed.provisioner_app import ProvisionerApp
 from nitrokey.updates import OverwriteError
 
@@ -29,6 +29,7 @@ from pynitrokey.cli.exceptions import CliException
 from pynitrokey.helpers import (
     DownloadProgressBar,
     Retries,
+    local_critical,
     local_print,
     require_windows_admin,
 )
@@ -182,8 +183,9 @@ def fetch_update(
     download a specific version, use the --version option.
     """
     try:
-        release = ctx.model.firmware_repository.get_release_or_latest(version)
-        update = release.require_asset(ctx.model.firmware_pattern)
+        firmware_repository = updates.get_firmware_repository(ctx.model)
+        release = firmware_repository.get_release_or_latest(version)
+        update = updates.get_firmware_update(ctx.model, release)
     except Exception as e:
         if version:
             raise CliException(f"Failed to find firmware update {version}", e)
@@ -265,21 +267,16 @@ def provision_fido2(
 
     if len(key) != 36:
         raise CliException(f"Invalid key length {len(key)} (expected 36)")
-    ecdsa_key = SigningKey.from_string(key[4:], curve=NIST256p)
-    pem_pubkey = serialization.load_pem_public_key(
-        ecdsa_key.get_verifying_key().to_pem()
-    )
-
+    ec_key = ec.derive_private_key(int(key[4:].hex(), 16), ec.SECP256R1())
+    ec_pubkey = ec_key.public_key()
     x509_cert = x509.load_der_x509_certificate(cert)
     cert_pubkey = x509_cert.public_key()
 
-    if not isinstance(pem_pubkey, EllipticCurvePublicKey):
-        raise CliException("The FIDO2 attestation key is not an EC key")
-    if not isinstance(cert_pubkey, EllipticCurvePublicKey):
+    if not isinstance(cert_pubkey, ec.EllipticCurvePublicKey):
         raise CliException(
             "The FIDO2 attestation certificate does not contain an EC key"
         )
-    if pem_pubkey.public_numbers() != cert_pubkey.public_numbers():
+    if ec_pubkey.public_numbers() != cert_pubkey.public_numbers():
         raise CliException(
             "The FIDO2 attestation certificate does not match the public key"
         )
@@ -390,6 +387,25 @@ def rng(ctx: Context[Bootloader, Device], length: int) -> None:
             length -= len(rng)
 
 
+def print_status(version: Version, status: Status) -> None:
+    local_print(f"Firmware version:   {version}")
+    if status.init_status is not None:
+        local_print(f"Init status:        {status.init_status}")
+    if status.ifs_blocks is not None:
+        local_print(f"Free blocks (int):  {status.ifs_blocks}")
+    if status.efs_blocks is not None:
+        local_print(f"Free blocks (ext):  {status.efs_blocks}")
+    if status.variant is not None:
+        local_print(f"Variant:            {status.variant.name}")
+
+    # Print at the end so that other status info are written
+    if status.init_status is not None:
+        if status.init_status & InitStatus.EXT_FLASH_NEED_REFORMAT:
+            local_critical(
+                "EFS is corrupted, please contact support for information on how to solve this issue"
+            )
+
+
 @click.command()
 @click.pass_obj
 def status(ctx: Context[Bootloader, Device]) -> None:
